==> modx-2.0.5-pl-ja.zip: modx-2.0.5-pl-ja/core/lexicon/ja/context.inc.php <==
<?php
/**
 * Context Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['context'] = 'コンテキスト';
$_lang['context_add'] = 'コンテキストを追加';
$_lang['context_create'] = 'コンテキストを作成';
$_lang['context_data'] = 'コンテキストデータ';
$_lang['context_duplicate'] = 'コンテキストの複製';
$_lang['context_err_ae'] = '同じ名前のコンテキストが存在します。';
$_lang['context_err_create'] = 'コンテキストの作成中にエラーが発生しました。';
$_lang['context_err_duplicate'] = 'コンテキストのコピー中にエラーが発生しました。';
$_lang['context_err_load_data'] = 'コンテキストデータの読み込みエラーです。';
$_lang['context_err_nf'] = 'コンテキストが見つかりません';
$_lang['context_err_nfs'] = 'キー[[+key]]のコンテキストが見つかりません。';
$_lang['context_err_ns'] = 'コンテキストが指定されていません。';
$_lang['context_err_ns_key'] = 'コンテキストの有効なキーを指定してください。';
$_lang['context_err_remove'] = 'コンテキストの削除中にエラーが発生しました。';
$_lang['context_err_save'] = 'コンテキストの保存中にエラーが発生しました。';
$_lang['context_id'] = 'コンテキストID';
$_lang['context_key'] = 'コンテキストキー';
$_lang['context_management_message'] = 'サイトのコンテキストを管理します。複数サイトを管理・運用する場合に、必要なサイトの数だけコンテキストを作成し、コントローラーファイル(index.php)内で関連付けて運用します。管理画面もMODxを利用して作られていますので、ここでコンテキストを管理しています。';
$_lang['context_refresh'] = 'コンテキストの再読み込み';
$_lang['context_remove'] = 'コンテキストを削除';
$_lang['context_remove_confirm'] = '本当にこのコンテキストを削除しますか？復活できません。';
$_lang['context_settings'] = 'コンテキスト設定';
$_lang['context_settings_desc'] = 'サイトごとのコンテキストを設定します。コンテキストは、サイト単位の「システム設定」のようなものです。たとえばsite_start ・base_url・http_host・site_urlなどをここで設定します。定義しない値に関してはグローバルのシステム設定の値が継承されます。';
$_lang['context_update'] = 'コンテキストを編集';
$_lang['context_with_key_not_found'] = 'キー%sのコンテキストが見つかりません';
$_lang['contexts'] = 'コンテキスト';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/context.inc.php <==
<?php
/**
 * Context English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['context'] = 'コンテキスト';
$_lang['context_add'] = 'コンテキストを追加';
$_lang['context_create'] = 'コンテキストを作成';
$_lang['context_data'] = 'コンテキストデータ';
$_lang['context_duplicate'] = 'コンテキストの複製';
$_lang['context_err_ae'] = '同じ名前のコンテキストが存在します。';
$_lang['context_err_create'] = 'コンテキストの作成中にエラーが発生しました。';
$_lang['context_err_duplicate'] = 'コンテキストのコピー中にエラーが発生しました。';
$_lang['context_err_load_data'] = 'コンテキストデータの読み込みエラーです。';
$_lang['context_err_nf'] = 'コンテキストが見つかりません。';
$_lang['context_err_nfs'] = 'キー[[+key]]のコンテキストが見つかりません。';
$_lang['context_err_ns'] = 'コンテキストが指定されていません。';
$_lang['context_err_ns_key'] = 'コンテキストの有効なキーを指定してください。';
$_lang['context_err_remove'] = 'コンテキストの削除中にエラーが発生しました。';
$_lang['context_err_save'] = 'コンテキストの保存中にエラーが発生しました。';
$_lang['context_id'] = 'コンテキストID';
$_lang['context_key'] = 'コンテキストキー';
$_lang['context_management_message'] = 'サイトのコンテキストを管理します。複数サイトを管理・運用する場合に、必要なサイトの数だけコンテキストを作成し、コントローラーファイル（index.php）内で関連付けて運用します。管理画面もMODXを利用して作られていますので、ここでコンテキストを管理しています。';
$_lang['context_refresh'] = 'コンテキストの再読み込み';
$_lang['context_remove'] = 'コンテキストを削除';
$_lang['context_remove_confirm'] = '本当にこのコンテキストを削除しますか？　復活できません。';
$_lang['context_settings'] = 'コンテキスト設定';
$_lang['context_settings_desc'] = 'サイトごとのコンテキストを設定します。コンテキストは、サイト単位の「システム設定」のようなものです。たとえばsite_start ・base_url・http_host・site_urlなどをここで設定します。定義しない値に関してはグローバルのシステム設定の値が継承されます。';
$_lang['context_update'] = 'コンテキストを編集';
$_lang['context_with_key_not_found'] = 'キー %s のコンテキストが見つかりません。';
$_lang['contexts'] = 'コンテキスト';
